==========
pypixplore
==========

This is the documentation of **pypixplore**.

.. note::

    This is the First release of Pypixplorer!

    We hope you enjoy this tool an let us know how we can improve it to make it even more useful.

    To make suggestions or report bugs got to our `github site <https://github.com/fccoelho/pypixplorer>`__.



Overview
========

PyPIExplorer is a library developed to facilitate the exploration of the `Python Package Index <http://pypi.python.org/pypi>`__.
Embedding data science and visualization techniques, this library helps you to better explore the scope of this large Python software repository.

Contents
========

.. toctree::
   :maxdepth: 2

          Quickstart <quickstart>
   License <license>
   Authors <authors>
   Changelog <changes>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
